summaryrefslogtreecommitdiffstats
path: root/kjsembed/tools/headers/qtimer.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/tools/headers/qtimer.h')
-rw-r--r--kjsembed/tools/headers/qtimer.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/kjsembed/tools/headers/qtimer.h b/kjsembed/tools/headers/qtimer.h
index 311e5e08..e61b4124 100644
--- a/kjsembed/tools/headers/qtimer.h
+++ b/kjsembed/tools/headers/qtimer.h
@@ -1,7 +1,7 @@
/****************************************************************************
**
**
** Definition of TQTimer class
**
** Created : 931111
**
@@ -11,7 +11,7 @@
**
** This file may be distributed under the terms of the Q Public License
** as defined by Trolltech AS of Norway and appearing in the file
-** LICENSE.QPL included in the packaging of this file.
+** LICENSE.TQPL included in the packaging of this file.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
@@ -27,7 +27,7 @@
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
** information about Qt Commercial License Agreements.
-** See http://www.trolltech.com/qpl/ for QPL licensing information.
+** See http://www.trolltech.com/qpl/ for TQPL licensing information.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
@@ -35,20 +35,20 @@
**
**********************************************************************/
-#ifndef QTIMER_H
-#define QTIMER_H
+#ifndef TQTIMER_H
+#define TQTIMER_H
#ifndef QT_H
#include "tqobject.h"
#endif // QT_H
-class Q_EXPORT TQTimer : public QObject
+class Q_EXPORT TTQTimer : public TQObject
{
Q_OBJECT
public:
- TQTimer( TQObject *parent=0, const char *name=0 );
- ~TQTimer();
+ TTQTimer( TTQObject *parent=0, const char *name=0 );
+ ~TTQTimer();
bool isActive() const;
@@ -56,7 +56,7 @@ public:
void changeInterval( int msec );
void stop();
- static void singleShot( int msec, TQObject *receiver, const char *member );
+ static void singleShot( int msec, TTQObject *receiver, const char *member );
int timerId() const { return id; }
@@ -64,7 +64,7 @@ signals:
void timeout();
protected:
- bool event( TQEvent * );
+ bool event( TTQEvent * );
private:
int id;
@@ -73,16 +73,16 @@ private:
private: // Disabled copy constructor and operator=
#if defined(Q_DISABLE_COPY)
- TQTimer( const TQTimer & );
- TQTimer &operator=( const TQTimer & );
+ TTQTimer( const TTQTimer & );
+ TTQTimer &operator=( const TTQTimer & );
#endif
};
-inline bool TQTimer::isActive() const
+inline bool TTQTimer::isActive() const
{
return id >= 0;
}
-#endif // QTIMER_H
+#endif // TQTIMER_H
@@ -1,7 +1,7 @@
**
**
-** Definition of TQTimer class
+** Definition of TTQTimer class
**
** Created : 931111